@@ -3,6 +3,7 @@ An enhanced ``pprint.pformat`` that prints data structures in a readable HTML st
 """
 
 from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
+from django.core.urlresolvers import NoReverseMatch
 from django.db import IntegrityError
 from django.db.models.base import Model
 from django.db.models.manager import Manager
@@ -174,8 +175,8 @@ def pformat_dict_summary_html(dict):
     return _style_text(u'{' + u',\n '.join(text) + u'}')
 
 
-# All regexes start with a space or '[', so the start of an element is detected.
-_start = r'([\[ ])'
+# The start marker helps to detect the beginning of a new element.
+_start = r'([{\[ ])'  # Allow to start with {, [ or space.
 RE_PROXY = re.compile(escape(_start + r'<django.utils.functional.__proxy__ object at 0x[0-9a-f]+>'))
 RE_FUNCTION = re.compile(escape(_start + r'<function [^ ]+ at 0x[0-9a-f]+>'))
 RE_GENERATOR = re.compile(escape(_start + r'<generator object [^ ]+ at 0x[0-9a-f]+>'))
@@ -250,7 +251,9 @@ def _format_lazy(value):
 def _try_call(func, extra_exceptions=()):
     try:
         return func()
-    except (TypeError, KeyError, AttributeError, ValueError, ObjectDoesNotExist, MultipleObjectsReturned, IntegrityError, AssertionError, NotImplementedError) as e:
+    except (TypeError, KeyError, AttributeError, ValueError,
+            ObjectDoesNotExist, MultipleObjectsReturned, IntegrityError, NoReverseMatch,
+            AssertionError, NotImplementedError) as e:
         return e
     except extra_exceptions as e:
         return e
